@@ -80,9 +80,9 @@ class PluginSubliminal(object):
         alts = set([Language(s) for s in config.get('alternatives', [])])
         for entry in task.accepted:
             if not 'location' in entry:
-                entry.reject('is not a local file')
+                log.warning('Cannot act on entries that do not represent a local file.')
             elif not os.path.exists(entry['location']):
-                entry.reject('file not found')
+                entry.fail('file not found: %s' % entry['location'])
             elif not '$RECYCLE.BIN' in entry['location']:  # ignore deleted files in Windows shares
                 try:
                     video = subliminal.scan_video(entry['location'])
@@ -93,9 +93,9 @@ class PluginSubliminal(object):
                         log.info('Subtitles found for %s' % entry['location'])
                     elif alts and (alts - video.subtitle_languages) and \
                         subliminal.download_best_subtitles([video], alts, min_score=msc):
-                        entry.reject('subtitles found for a second-choice language.')
+                        entry.fail('subtitles found for a second-choice language.')
                     else:
-                        entry.reject('cannot find any subtitles for now.')
+                        entry.fail('cannot find any subtitles for now.')
                 except Exception as err:
                     # don't want to abort the entire task for errors in a  
                     # single video file or for occasional network timeouts
